@@ -76,7 +76,7 @@ class URLMap(models.Model):
     force_secure = models.BooleanField(default=False)
     hexdigest = models.CharField(max_length=255, db_index=True, blank=True,
                                  unique=True)
-    status_code = models.IntegerField(default=200)
+    status_code = models.IntegerField(default=200, db_index=True)
     redirect = models.ForeignKey(
         'self', related_name='redirects', blank=True, null=True)
     content_map = models.ForeignKey(ContentMap, blank=True, null=True)
