@@ -22,68 +22,12 @@ from django.test import TestCase as DjangoTestCase
 from django.test.client import RequestFactory
 from django_any.contrib import any_user
 from override_settings import override_settings
+from test_extensions import TestCase
 import mox
 
 from urlographer import models, utils, views
 
 
-class TestCase(DjangoTestCase):
-
-    def assertRaisesMessage(self, excClass, callableObj, excMessage,
-                            *args, **kwargs):
-        try:
-            callableObj(*args, **kwargs)
-        except excClass, e:
-            # message_dict and messages for Django's ValidationError
-            if hasattr(e, 'message_dict'):
-                e.message = e.message_dict
-            elif hasattr(e, 'messages'):
-                e.message = e.messages
-
-            if e.message != excMessage:
-                raise AssertionError(
-                    '%s message does not match %r, actual message: %r' %
-                    (excClass.__name__, excMessage, e.message))
-        else:
-            raise AssertionError('%s not raised' % excClass.__name__)
-
-
-class TestCaseTest(TestCase):
-    def raise_error(self, error_message, exc=ValidationError):
-        raise exc(error_message)
-
-    def test_raises_message_return_message(self):
-        self.assertRaisesMessage(
-            Exception, self.raise_error, 'test message',
-            error_message='test message', exc=Exception)
-
-    def test_raises_message_return_messages_list(self):
-        self.assertRaisesMessage(
-            ValidationError, self.raise_error, ['test message1', 'message2'],
-            error_message=['test message1', 'message2'])
-
-    def test_raises_message_return_message_dict(self):
-        self.assertRaisesMessage(
-            ValidationError, self.raise_error, {'field': 'test message1'},
-            error_message={'field': 'test message1'})
-
-    def test_raises_message_messages_dont_match(self):
-        # Assert that assertRaisesMessage raises AssertionError when messages
-        # don't match
-        self.assertRaises(
-            AssertionError,
-            self.assertRaisesMessage, ValidationError, self.raise_error,
-            ['test message1'], error_message=['message2'])
-
-    def test_raises_message_specified_exception_not_raised(self):
-        # Assert that assertRaisesMessage raises AssertionError when sprcified
-        # exception is not raised
-        self.assertRaisesMessage(
-            AssertionError,
-            self.assertRaisesMessage, 'ValidationError not raised',
-            ValidationError, str, 'test message')
-
-
 class URLMapTest(TestCase):
     def setUp(self):
         self.site = Site(domain='example.com')
@@ -191,7 +135,7 @@ class URLMapTest(TestCase):
         self.assertRaisesMessage(
             ValidationError, self.url.save,
             {'hexdigest': [u'Url map with this Hexdigest already exists.']})
-        
+
 
 class URLMapManagerTest(TestCase):
     def setUp(self):
